@@ -1,4 +1,6 @@
 zn.binom <- function(se.p, pstar, se.u = 1) {
   n <- log(1 - se.p) / log(1 - pstar * se.u)
-  return(ceiling(n))
+  
+  rval <- ceiling(n)
+  return(rval)
 }
